==> s-0.2.tar.obj: s-0.2/configure.py <==
#!/usr/bin/env python

import glob
import os
import sys
import sipconfig


def replace(filename, postfix, pairs):
    '''Replace in filename the first string with the second string for each
    pair in pairs, backing up the original file postfixed by postfix.
    '''
 
    if not os.access(filename, os.W_OK):
        return
    old = open(filename).read()
    new = old[:]
    for bad, good in pairs:
        new = new.replace(bad, good)
    if old != new:
        backup = filename + postfix
        try:
            os.unlink(backup)
        except os.error:
            pass
        try:
            os.rename(filename, backup)
        except os.error:
            pass
        open(filename, 'w').write(new)

# replace()


if __name__ == '__main__':
    config = sipconfig.Configuration()
    build_file = "s.sbf"

    os.system(" ".join(
        [config.sip_bin, "-c", ".", "-b", build_file, "s.sip"]
        ))

    makefile = sipconfig.SIPModuleMakefile(config, build_file)
    makefile.generate()

    if len(sys.argv) > 1: # patches SIP output
        for filename in glob.glob('*.fix'):
            os.remove(filename)
            
        for filename, todo in {
            'sipsB.cpp': (('B::bar()',
                           'A::bar()'),
                          ('sipRes = sipB::sipProtect_bar()',
                           'sipRes = sipA::sipProtect_bar()'),
                          ),
            'sipsE.cpp': (('#include "sipsD.h"',
                           os.linesep.join(['#include "sipsC.h"',
                                            '#include "sipsD.h"'])),
                          ),
            }.iteritems():
            replace(filename, '.fix', todo)
    
# Local Variables: ***
# mode: python ***
# End: ***

==> s-0.3.tar.obj: s-0.3/configure.py <==
#!/usr/bin/env python

import glob
import os
import sys
import sipconfig


def replace(filename, postfix, pairs):
    '''Replace in filename the first string with the second string for each
    pair in pairs, backing up the original file postfixed by postfix.
    '''
 
    if not os.access(filename, os.W_OK):
        return
    old = open(filename).read()
    new = old[:]
    for bad, good in pairs:
        new = new.replace(bad, good)
    if old != new:
        backup = filename + postfix
        try:
            os.unlink(backup)
        except os.error:
            pass
        try:
            os.rename(filename, backup)
        except os.error:
            pass
        open(filename, 'w').write(new)

# replace()


if __name__ == '__main__':
    config = sipconfig.Configuration()
    build_file = "s.sbf"

    os.system(" ".join(
        [config.sip_bin, "-c", ".", "-b", build_file, "s.sip"]
        ))

    makefile = sipconfig.SIPModuleMakefile(config, build_file)
    makefile.generate()

    if len(sys.argv) > 1: # patches SIP output
        for filename in glob.glob('*.fix'):
            os.remove(filename)
            
        for filename, todo in {
##             'sipsB.cpp': (('B::bar()',
##                            'A::bar()'),
##                           ('sipRes = sipB::sipProtect_bar()',
##                            'sipRes = sipA::sipProtect_bar()'),
##                           ),
            'sipsE.cpp': (('#include "sipsD.h"',
                           os.linesep.join(['#include "sipsC.h"',
                                            '#include "sipsD.h"'])),
                          ),
            }.iteritems():
            replace(filename, '.fix', todo)
    
# Local Variables: ***
# mode: python ***
# End: ***
